@@ -14,11 +14,11 @@
     </message>
     <message>
         <source>Use theme&apos;s wallpapers</source>
-        <translation type="unfinished"></translation>
+        <translation>Utiliser les fonds d&apos;écran du thème</translation>
     </message>
     <message>
         <source>Keep my current wallpapers</source>
-        <translation type="unfinished"></translation>
+        <translation>Conserver mes fonds d&apos;écran actuel</translation>
     </message>
     <message>
         <source>Theme customizations applied!</source>
